OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Tehtävät",
    "Due yesterday" : "Eräpäivä eilen",
    "Due today" : "Eräpäivä tänään",
    "Due tomorrow" : "Eräpäivä huomenna",
    "Due on" : "Eräpäivä",
    "Started yesterday" : "Alkoi eilen",
    "Starts today" : "Alkaa tänään",
    "Starts tomorrow" : "Alkaa huomenna",
    "Started on" : "Aloitettu",
    "Starts on" : "Alkaa",
    "[Remind me yesterday at ]HH:mm" : "[Muistuta minua klo ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Muistuta minua tänään klo ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Muistuta minua huomenna klo ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Muistuta minua ]MMM DD, YYYY [ klo ]HH:mm",
    "Yesterday" : "Eilen",
    "Today" : "Tänään",
    "Tomorrow" : "Huomenna",
    "in %s" : "polussa %s",
    "%s ago" : "%s sitten",
    "seconds" : "sekuntia",
    "a minute" : "minuutti",
    "%d minutes" : "%d minuuttia",
    "an hour" : "tunti",
    "%d hours" : "%d tuntia",
    "a day" : "päivä",
    "%d days" : "%d päivää",
    "a month" : "kuukausi",
    "%d months" : "%d kuukautta",
    "a year" : "vuosi",
    "%d years" : "%d vuotta",
    "week" : "viikko",
    "weeks" : "viikkoa",
    "day" : "päivä",
    "days" : "päivän jälkeen",
    "hour" : "tunti",
    "hours" : "tuntia",
    "minute" : "minuutti",
    "minutes" : "minuuttia",
    "second" : "toinen",
    "before beginning" : "ennen alkua",
    "after beginning" : "alun jälkeen",
    "before end" : "ennen loppua",
    "after end" : "lopun jälkeen",
    "Comment" : "Kommentti",
    "Add a comment" : "Lisää kommentti",
    "This will delete the calendar \"%s\" and all corresponding events and tasks." : "Tämä poistaa kalenterin \"%s\" ja kaikki sitä vastaavat tapahtumat sekä tehtävät.",
    "The name \"%s\" is already used." : "Nimi \"%s\" on jo käytössä.",
    "An empty name is not allowed." : "Nimi ei voi olla tyhjä.",
    "Hidden" : "Piilotettu",
    "Visible" : "Näkyvissä",
    "Automatic" : "Automaattinen",
    "Sunday" : "sunnuntai",
    "Monday" : "maanantai",
    "Tuesday" : "tiistai",
    "Wednesday" : "keskiviikko",
    "Thursday" : "torstai",
    "Friday" : "perjantai",
    "Saturday" : "lauantai",
    "Add an important item in \"%s\"..." : "Lisää tärkeä tietue kohteeseen \"%s\"...",
    "Add an item due today in \"%s\"..." : "Lisää tietue erääntymään tänään \"%s\"...",
    "Add an item in \"%s\"..." : "Lisää tietue kohteeseen \"%s\"...",
    "Add a current item in \"%s\"..." : "Lisää %s:ään...",
    "Add a subtask to \"%s\"..." : "Lisää alitehtävä kohteeseen \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n valmistunut tehtävä","%n valmistunutta tehtävää"],
    "Hours" : "Tunnit",
    "Minutes" : "Minuutit",
    "Set due date" : "Aseta eräpäivä",
    "%s %% completed" : "%s %% valmiina",
    "priority %s: " : "prioriteetti %s: ",
    "high" : "korkea",
    "medium" : "keskitaso",
    "low" : "matala",
    "no priority assigned" : "prioriteettia ei ole asetettu",
    "Remind me" : "Muistuta minua",
    "at the end" : "lopussa",
    "at the beginning" : "alussa",
    "Set start date" : "Aseta aloituspäivä",
    "{calendar} shared by {owner}" : "{calendar} jakanut {owner}",
    "Unnamed" : "Nimetön",
    "Important" : "Tärkeä",
    "Week" : "Viikko",
    "All" : "Kaikki",
    "Current" : "Nykyinen",
    "Completed" : "Valmiina",
    "The Tasks app for Nextcloud" : "Tehtäväsovellus Nextcloudille",
    "Delete" : "Poista",
    "Cancel" : "Peruuta",
    "Edit" : "Muokkaa",
    "Link" : "Linkki",
    "Download" : "Lataa",
    "Save" : "Tallenna",
    "Add List..." : "Lisää luettelo...",
    "New List" : "Uusi luettelo",
    "Settings" : "Asetukset",
    "Start of week" : "Viikon alku",
    "Visibility of Smart Collections" : "Älykkäiden kokoelmien näkyvyys",
    "Change sort order" : "Muuta järjestystä",
    "Default" : "Oletus",
    "Due date" : "Eräpäivä",
    "Start date" : "Aloituspäivä",
    "Priority" : "Tärkeys",
    "Alphabetically" : "Aakkosjärjestys",
    "Manually" : "Käsin",
    "Load remaining completed tasks." : "Lataa loput valmistuneet tehtävät.",
    "Task is completed" : "Tehtävä on valmis",
    "All day" : "Koko päivä",
    "(New category)" : "(Uusi luokka)",
    "Select categories..." : "Valitse luokat...",
    "Loading the task..." : "Ladataan tehtävää...",
    "Task not found!" : "Tehtävää ei löytynyt!",
    "add a subtask to" : "lisää alitehtävä tehtävälle"
},
"nplurals=2; plural=(n != 1);");
